@@ -7,7 +7,9 @@ from django.http import HttpResponse
 from wagtail.admin.edit_handlers import FieldPanel
 from wagtail.core.models import Page
 from wagtail.documents.edit_handlers import DocumentChooserPanel
-from webspace.cms.models import MyDocument
+from webspace.loader import get_model
+
+MyDocument = get_model('cms', 'MyDocument')
 
 
 class ADocumentPage(Page):
