@@ -15,7 +15,7 @@ def robots(request):
     )
 
 
-def error_404(request, exception):
+def error_404(request, exception=None):
     context = {}
     context['icons'] = IconSnippet.get_context()
     return render(request, 'cms/pages/404.html', context, status=404)
